## Nursery

__Your Star is Born__

Nursery is a cloud, virtual machine, and container provisioning tool. It uses a plugin system to install any targets you like that someone wrote a plugin for. Pip install this repo and any plugins, and then use them through the cli. `nursery --help` will get you started.

Nursery is in very early development and may make any breaking changes without notice.
